StringExt

Trait StringExt 

pub trait StringExt {
    // Required methods
    fn is_lowercase(&self) -> bool;
    fn starts_with_lowercase(&self) -> bool;
    fn to_lowercase_first(&self) -> String;
    fn to_uppercase_first(&self) -> String;
}
Additional methods for strings

Required Methods

fn is_lowercase(&self) -> bool

Checks if the string is all lowercase

fn starts_with_lowercase(&self) -> bool

Checks if a string starts with a lowercase character

fn to_lowercase_first(&self) -> String

Returns a new string starting with a first character in lowercase

fn to_uppercase_first(&self) -> String

Returns a new string starting with a first character in uppercase

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl StringExt for str

Implementors